@@ -1,6 +1,7 @@
 import shlex
 import subprocess
 import time
+from tarfile import TarFile
 
 import pytest
 
@@ -54,17 +55,24 @@ def ssh():
         stop_docker(name)
 
 
-def test_simple(ssh):
+@pytest.fixture(scope="module")
+def root_path():
+    return "/home/someuser/"
+
+
+def test_simple(ssh, root_path):
     f = fsspec.get_filesystem_class("sftp")(**ssh)
-    f.mkdirs("/home/someuser/deeper")
-    f.touch("/home/someuser/deeper/afile")
-    assert f.find("/home/someuser") == ["/home/someuser/deeper/afile"]
-    assert f.ls("/home/someuser/deeper/") == ["/home/someuser/deeper/afile"]
-    assert f.info("/home/someuser/deeper/afile")["type"] == "file"
-    assert f.info("/home/someuser/deeper/afile")["size"] == 0
-    assert f.exists("/home/someuser")
-    f.rm("/home/someuser", recursive=True)
-    assert not f.exists("/home/someuser")
+    f.mkdirs(root_path + "deeper")
+    try:
+        f.touch(root_path + "deeper/afile")
+        assert f.find(root_path) == [root_path + "deeper/afile"]
+        assert f.ls(root_path + "deeper/") == [root_path + "deeper/afile"]
+        assert f.info(root_path + "deeper/afile")["type"] == "file"
+        assert f.info(root_path + "deeper/afile")["size"] == 0
+        assert f.exists(root_path)
+    finally:
+        f.rm(root_path, recursive=True)
+        assert not f.exists(root_path)
 
 
 @pytest.mark.parametrize("protocol", ["sftp", "ssh"])
@@ -85,23 +93,73 @@ def test_with_url(protocol, ssh):
         assert f.read() == b"hello"
 
 
-def test_transaction(ssh):
-    f = fsspec.get_filesystem_class("sftp")(**ssh)
-    f.mkdirs("/home/someuser/deeper")
-    f.start_transaction()
-    f.touch("/home/someuser/deeper/afile")
-    assert f.find("/home/someuser") == []
-    f.end_transaction()
-    f.find("/home/someuser") == ["/home/someuser/deeper/afile"]
+@pytest.fixture(scope="module")
+def netloc(ssh):
+    username = ssh.get("username")
+    password = ssh.get("password")
+    host = ssh.get("host")
+    port = ssh.get("port")
+    userpass = (
+        username + ((":" + password) if password is not None else "") + "@"
+        if username is not None
+        else ""
+    )
+    netloc = host + ((":" + str(port)) if port is not None else "")
+    return userpass + netloc
 
-    with f.transaction:
-        assert f._intrans
-        f.touch("/home/someuser/deeper/afile2")
-        assert f.find("/home/someuser") == ["/home/someuser/deeper/afile"]
-    assert f.find("/home/someuser") == [
-        "/home/someuser/deeper/afile",
-        "/home/someuser/deeper/afile2",
-    ]
+
+def test_simple_with_tar(ssh, netloc, tmp_path, root_path):
+
+    files_to_pack = ["a.txt", "b.txt"]
+
+    tar_filename = make_tarfile(files_to_pack, tmp_path)
+
+    f = fsspec.get_filesystem_class("sftp")(**ssh)
+    f.mkdirs(root_path + "deeper", exist_ok=True)
+    try:
+        remote_tar_filename = root_path + "deeper/somefile.tar"
+        with f.open(remote_tar_filename, mode="wb") as wfd:
+            with open(tar_filename, mode="rb") as rfd:
+                wfd.write(rfd.read())
+        fs = fsspec.open("tar::ssh://" + netloc + remote_tar_filename).fs
+        files = fs.find("/")
+        assert files == files_to_pack
+    finally:
+        f.rm(root_path, recursive=True)
+
+
+def make_tarfile(files_to_pack, tmp_path):
+    """Create a tarfile with some files."""
+    tar_filename = tmp_path / "sometarfile.tar"
+    for filename in files_to_pack:
+        with open(tmp_path / filename, mode="w") as fd:
+            fd.write("")
+    with TarFile(tar_filename, mode="w") as tf:
+        for filename in files_to_pack:
+            tf.add(tmp_path / filename, arcname=filename)
+    return tar_filename
+
+
+def test_transaction(ssh, root_path):
+    f = fsspec.get_filesystem_class("sftp")(**ssh)
+    f.mkdirs(root_path + "deeper", exist_ok=True)
+    try:
+        f.start_transaction()
+        f.touch(root_path + "deeper/afile")
+        assert f.find(root_path) == []
+        f.end_transaction()
+        assert f.find(root_path) == [root_path + "deeper/afile"]
+
+        with f.transaction:
+            assert f._intrans
+            f.touch(root_path + "deeper/afile2")
+            assert f.find(root_path) == [root_path + "deeper/afile"]
+        assert f.find(root_path) == [
+            root_path + "deeper/afile",
+            root_path + "deeper/afile2",
+        ]
+    finally:
+        f.rm(root_path, recursive=True)
 
 
 def test_makedirs_exist_ok(ssh):
